Coverage for /home/delusionalinsanity/bbrepos/matyan/src/matyan/constants.py: 100%

# Coverage for /home/delusionalinsanity/bbrepos/matyan/src/matyan/constants.py : 100%

## 6 statements 6 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | __author__ = 'Artur Barseghyan' __copyright__ = '2019 Artur Barseghyan' __license__ = 'GPL-2.0-only OR LGPL-2.0-or-later' __all__ = ( 'PRETTY_FORMAT', 'TICKET_NUMBER_OTHER', ) PRETTY_FORMAT = '{' \ '"commit_hash": "%H", ' \ '"commit_abbr": "%h", ' \ '"datetime": "%ci", ' \ '"title": "%s",' \ '"author": "%an", ' \ '"author_email": "%ae", ' \ '"merge": "%P"' \ '}' TICKET_NUMBER_OTHER = 'other'